@@ -210,6 +210,14 @@ class LofarHBAPrimaryBeam(PrimaryBeam):
         PrimaryBeam.__init__(self, 30.75, 1.02, 'gaussian')
 
 
+class AartfaacA12HBAPrimaryBeam(PrimaryBeam):
+
+    name = 'a12_hba'
+
+    def __init__(self):
+        PrimaryBeam.__init__(self, 5, 1.02, 'gaussian')
+
+
 class LofarLBAInnerPrimaryBeam(PrimaryBeam):
 
     name = 'lofar_lba_inner'
