@@ -14,6 +14,8 @@ import numpy as np
 
 from scipy.special import comb
 from scipy import stats
+from scipy.optimize import minimize_scalar, brute, fmin
+
 from sklearn.decomposition import PCA
 
 import GPy
@@ -66,6 +68,7 @@ class GprConfig(object):
         self.noise_scale_search_n_restarts = 2
         self.noise_scale_search_maxiter = 15
         self.use_simulated_noise = False
+        self.simulated_noise_scale_kper = True
 
         self.num_restarts = 10
 
@@ -126,6 +129,38 @@ class GprResult(object):
         self.cov_err = cov_err
         self.y_scale = y_scale
 
+    def test_single_parameter(self, param_name, min_value, max_value, n_optimize_loop=2,
+                              tol=1e-3, verbose=False, method='bounded', brute_ns=20):
+        model = self.model.copy()
+        p = get_model_parameter(model, param_name)
+
+        def func(v):
+            if v < 0:
+                return 1e99
+
+            p.constrain_fixed(v)
+            model.optimize_restarts(n_optimize_loop, verbose=False)
+
+            if verbose:
+                print('Test:', v, - model.log_likelihood() - model.log_prior())
+
+            return - model.log_likelihood() - model.log_prior()
+
+        def brute_finish(fct, pos, args):
+            return fmin(fct, pos, xtol=tol, ftol=tol, maxiter=brute_ns, full_output=1, disp=0)
+
+        if method == 'brute':
+            res = brute(func, [(min_value, max_value)], Ns=brute_ns, finish=brute_finish)
+            x0 = res[0]
+        elif method == 'bounded':
+            res = minimize_scalar(func, tol=tol, bounds=[min_value, max_value], method='bounded')
+            x0 = res.x
+        else:
+            res = minimize_scalar(func, bracket=[min_value, max_value], tol=tol, method=method)
+            x0 = res.x
+
+        return x0
+
 
 class HeteroScaleGaussian(GPy.likelihoods.Likelihood):
     """
