@@ -423,14 +423,14 @@ def get_uv_bins(umin, umax, du):
     return psutil.pairwise(np.arange(umin, umax + du, du))
 
 
-def get_samples(X, n, K, complex_type=True, nearest_pd=True, method='cholesky'):
+def get_samples(X, n, K, complex_type=True, nearest_pd=True, method='svd'):
     '''Return n samples from the freq-freq covariance K'''
     if nearest_pd and not is_positive_definite(K):
         K = nearest_postive_definite(K)
     rg = np.random.default_rng()
     d = rg.multivariate_normal(np.zeros_like(X).squeeze(), K, n, method=method).T
     if complex_type:
-        d = d + 1j * np.random.multivariate_normal(np.zeros_like(X).squeeze(), K, n).T
+        d = d + 1j *rg.multivariate_normal(np.zeros_like(X).squeeze(), K, n, method=method).T
     return d
 
 
@@ -499,16 +499,11 @@ def c_nu_from_ps21_fct(ps3d_fct, freqs, uv_bins, delta_kpar=0.05, normalize=True
     delta_r = abs(r - r[0])
 
     d_delta_r = np.diff(delta_r).mean()
-    k_par = 2 * np.pi * np.fft.fftshift(np.fft.fftfreq(len(r), d_delta_r))
-    k_par = k_par[k_par >= 0]
+    k_par_max = np.pi  / d_delta_r
+    k_par = np.arange(0, k_par_max, k_par_max / len(r))
 
-    k_pers, k_pars = np.meshgrid(k_per, k_par)
-    ks = np.sqrt(k_pers ** 2 + k_pars ** 2)
-    
-    y = ps3d_fct(ks)[:, :, None] * np.cos(delta_r[None, None, :] * k_par[:, None, None])
-
-    c_nu_nu = np.abs(trapezoid(y, k_par, axis=0))
-    c_nu_nu[:, len(delta_r) // 2:] = 0
+    y = ps3d_fct(np.sqrt(k_per[None, :, None] ** 2 + k_par[:, None, None] ** 2)) * np.cos(delta_r[None, None, :] * k_par[:, None, None])
+    c_nu_nu = trapezoid(y, k_par, axis=0)
 
     if normalize:
         c_nu_nu = c_nu_nu / c_nu_nu.max()
@@ -654,10 +649,10 @@ class AbstractMLKern(MultiKern, GPy.kern.Kern):
         self.params_call = []
         MultiKern.__init__(self)
 
-    def set_latent_space_normal_prior(self):
+    def set_latent_space_normal_prior(self, nsigma=1):
         ''' Convenient function to set a Gaussian prior on the latent space parameters '''
         for param in self.parameters[:-1]:
-            param.set_prior(GPy.core.parameterization.priors.Gaussian(0, 1))
+            param.set_prior(GPy.core.parameterization.priors.Gaussian(0, nsigma))
 
     def set_variance_log10_prior(self, lower, upper):
         ''' Convenient function to set a Log10 prior on the variance parameters '''
@@ -1130,7 +1125,7 @@ class MCMCSampler(object):
         return self.sampler.get_chain().shape[-1]
 
     def run_mcmc(self, n_steps, n_walkers, lower_bound=None, upper_bound=None,
-                 verbose=False, debug=False, save_file=None, live_update=False):
+                 verbose=False, debug=False, save_file=None, live_update=False, emcee_moves='stretch'):
         ''' Run the MCMC smapler. If lower_bound/upper_bound is not set, 
             initial values will be sampled from the parameters priors.'''
 
@@ -1162,7 +1157,10 @@ class MCMCSampler(object):
                                     high=np.array(upper_bound)[:, None],
                                     size=(ndim, n_walkers)).T
 
-        moves = emcee.moves.StretchMove(a=1.75)
+        if emcee_moves == 'stretch':
+            moves = emcee.moves.StretchMove()
+        else:
+            moves = emcee_moves
         if save_file is not None:
             backend = emcee.backends.HDFBackend(save_file)
             backend.reset(n_walkers, ndim)
