@@ -1149,15 +1149,14 @@ class SpatialPowerSpectra(PowerSpectraMath):
             else:
                 ps = self.k_per ** 2 * ps / (2 * np.pi)
 
-        if log_norm:
-            norm = LogNorm()
-        else:
-            norm = None
+        if log_norm and 'norm' not in kargs:
+            kargs['norm'] = LogNorm(vmin=kargs.get('vmin'), vmax=kargs.get('vmax'))
+            kargs['vmin'] = None
+            kargs['vmax'] = None
 
         cbs = psutil.ColorbarSetting(psutil.ColorbarOutterPosition())
 
-        im_mappable = ax.imshow(ps, aspect='auto', norm=norm,
-                                extent=extent, **kargs)
+        im_mappable = ax.imshow(ps, aspect='auto', extent=extent, **kargs)
         cbs.add_colorbar(im_mappable, ax)
         ax.set_ylabel("Frequency (MHz)")
 
@@ -1330,10 +1329,10 @@ class CylindricalPowerSpectra(PowerSpectraMath):
             ax.set_xlabel('l')
             ax.set_ylabel("Delay (us)")
 
-        if log_norm:
-            norm = LogNorm()
-        else:
-            norm = None
+        if log_norm and 'norm' not in kargs:
+            kargs['norm'] = LogNorm(vmin=kargs.get('vmin'), vmax=kargs.get('vmax'))
+            kargs['vmin'] = None
+            kargs['vmax'] = None
 
         if colorbar:
             cbs = psutil.ColorbarSetting(psutil.ColorbarOutterPosition(pad=pad))
@@ -1348,7 +1347,7 @@ class CylindricalPowerSpectra(PowerSpectraMath):
             x = np.log10(self.k_per)
             y = np.log10(self.k_par)
             xx, yy = np.meshgrid(x, y)
-            im_mappable = ax.pcolormesh(xx, yy, self.data, norm=norm, **kargs)
+            im_mappable = ax.pcolormesh(xx, yy, self.data, **kargs)
 
             # Set the ticks to be in log scale
             major = np.arange(np.floor(x.min()), np.ceil(x.max()))
@@ -1367,7 +1366,7 @@ class CylindricalPowerSpectra(PowerSpectraMath):
             ax.set_xticklabels([r'$\mathregular{10^{%d}}$' % v for v in ax.get_xticks()])
             ax.set_yticklabels([r'$\mathregular{10^{%d}}$' % v for v in ax.get_yticks()])
         else:
-            im_mappable = ax.imshow(data, aspect='auto', norm=norm, extent=extent, **kargs)
+            im_mappable = ax.imshow(data, aspect='auto', extent=extent, **kargs)
 
         if colorbar:
             if ax_cb is None:
@@ -1661,10 +1660,10 @@ class MultiNight2DPowerSpectra(PowerSpectraMath):
         if ax is None:
             fig, ax = plt.subplots()
 
-        if log_norm:
-            norm = LogNorm()
-        else:
-            norm = None
+        if log_norm and 'norm' not in kargs:
+            kargs['norm'] = LogNorm(vmin=kargs.get('vmin'), vmax=kargs.get('vmax'))
+            kargs['vmin'] = None
+            kargs['vmax'] = None
 
         cbs = psutil.ColorbarSetting(psutil.ColorbarOutterPosition())
 
@@ -1673,7 +1672,7 @@ class MultiNight2DPowerSpectra(PowerSpectraMath):
         else:
             extent = (min(self.x), max(self.x), min(self.y), max(self.y))
 
-        im_mappable = ax.imshow(self.data, aspect='auto', norm=norm,
+        im_mappable = ax.imshow(self.data, aspect='auto',
                                 extent=extent, **kargs)
         if colorbar:
             cbs.add_colorbar(im_mappable, ax)
@@ -1868,7 +1867,7 @@ class CylindricalPowerSpectraMC(PowerSpectraMC, CylindricalPowerSpectra):
         if show68:
             ax.fill_between(x, q16, q84, alpha=kargs.get('alpha', 0.5), color=kargs.get('c', None))
         if show95:
-            ax.fill_between(x, q2_5, q97_5, alpha=0.5 * kargs.get('alpha', 0.25), color=kargs.get('c', None))
+            ax.fill_between(x, q2_5, q97_5, alpha=0.5 * kargs.get('alpha', 0.5), color=kargs.get('c', None))
 
         ax.plot(x, y, **kargs)
 
@@ -1902,7 +1901,7 @@ class CylindricalPowerSpectraMC(PowerSpectraMC, CylindricalPowerSpectra):
         if show68:
             ax.fill_between(x, q16, q84, alpha=kargs.get('alpha', 0.5), color=kargs.get('c', None))
         if show95:
-            ax.fill_between(x, q2_5, q97_5, alpha=0.5 * kargs.get('alpha', 0.25), color=kargs.get('c', None))
+            ax.fill_between(x, q2_5, q97_5, alpha=0.5 * kargs.get('alpha', 0.5), color=kargs.get('c', None))
 
         ax.plot(x, y, **kargs)
 
