@@ -16,11 +16,13 @@ import re
 import os
 import sys
 import time
+import functools
 import itertools
 import configparser
 
 from scipy import stats
 from scipy.sparse import diags
+from scipy.signal import get_window
 
 import numpy as np
 
@@ -365,6 +367,19 @@ def lssa_cov(x, C, M, dx=None):
     return np.linalg.pinv(np.dot(np.dot(A.real.T, W), A.real))
 
 
+def lssa_diag_cov(x, d, M=None, dx=None):
+    if M is None:
+        M = len(x)
+
+    if dx is None:
+        dx = robust_freq_width(x)
+
+    k = np.fft.fftshift(np.fft.fftfreq(M, float(dx)))
+    A = np.exp(-2. * np.pi * 1j * k * x[:, np.newaxis]) / len(x)
+    
+    return k, np.array([1 / np.diag(abs(np.dot(A.conj().T / d[:, i], A))) for i in range(d.shape[1])]).T
+
+
 def do_weighted_lssa(A, y, w):
     n_x, n_k = A.shape
     n_modes = y.shape[1]
@@ -972,29 +987,42 @@ def nwise(iterable, n):
     return list(zip(*ilist))
 
 
-def _get_next_oddeven(n, testeven):
+def _get_next_previous_oddeven(n, testeven, next=True):
     if isinstance(n, np.ndarray):
         if not n.dtype == np.int:
             n = n.astype(int)
         if (n % 2 == testeven).any():
             m = n.copy()
-            m[(n % 2 == testeven)] += 1
+            if next:
+                m[(n % 2 == testeven)] += 1
+            else:
+                m[(n % 2 == testeven)] -= 1
             return m
         return n
     else:
         if not isinstance(n, int):
             n = int(n)
         if n % 2 == testeven:
-            return n + 1
+            if next:
+                return n + 1
+            return n - 1
         return n
 
 
 def get_next_even(n):
-    return _get_next_oddeven(n, True)
+    return _get_next_previous_oddeven(n, True)
 
 
 def get_next_odd(n):
-    return _get_next_oddeven(n, False)
+    return _get_next_previous_oddeven(n, False)
+
+
+def get_previous_even(n):
+    return _get_next_previous_oddeven(n, True, next=False)
+
+
+def get_previous_odd(n):
+    return _get_next_previous_oddeven(n, False, next=False)
 
 
 def is_odd(num):
@@ -1050,6 +1078,7 @@ def get_beam(thetas, beam_type, fwhm, n_sidelobe):
     return beam
 
 
+@functools.lru_cache(maxsize=20, typed=False)
 def get_beam_cart(res, img_shape, beam_type, fwhm, n_sidelobe=None):
     nx, ny = img_shape
 
@@ -1060,6 +1089,20 @@ def get_beam_cart(res, img_shape, beam_type, fwhm, n_sidelobe=None):
     return get_beam(np.sqrt(thx ** 2 + thy ** 2), beam_type, fwhm, n_sidelobe)
 
 
+@functools.lru_cache(maxsize=20, typed=False)
+def generate_2d_window(window_name, nx, circular=False):
+    w = get_window(window_name, nx)
+    if circular:
+        m = (nx - 1) // 2
+        x = np.linspace(-m, m, nx)
+        xx, yy = np.meshgrid(x, x)
+        w2d = np.interp(np.sqrt(xx ** 2 + yy ** 2), x, w)
+    else:
+        w2d = np.outer(w, w)
+
+    return w2d
+  
+
 def robust_std_idl(inputData, Zero=False, axis=None, dtype=None):
     """
     Robust estimator of the standard deviation of a data set.
